validator

package
v1.0.2 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Feb 9, 2026 License: Apache-2.0 Imports: 3 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

var Module = fx.Module(
	"validator",
	fx.Decorate(func(log *zap.Logger) *zap.Logger {
		return log.Named("validator")
	}),
	fx.Provide(New),
)

Functions

func New

func New() *validator.Validate

New creates a new validator instance with required struct validation enabled. WithRequiredStructEnabled ensures that struct fields marked as required are validated even when the struct itself is not explicitly validated.

Types

type Validatable

type Validatable interface {
	Validate() error
}

type Validate

type Validate = validator.Validate

Jump to